==> docfbe_2_3_36_63.zip: docfbe_2_3_36_63/source/TCFbEColumnCachedTable.cpp <==
/*
    TCFbEColumnCachedTable.cpp    November 29, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#pragma hdrstop

#include "TCFbEColumnCachedTable.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
//---------------------------------------------------------------------------
// RXgN^iLbV쐬
__fastcall TCFbEColumnCachedTable::TCFbEColumnCachedTable(void)
    : TCFbECachedTable()
{
}

//---------------------------------------------------------------------------
// fXgN^
__fastcall TCFbEColumnCachedTable::~TCFbEColumnCachedTable()
{
}

//---------------------------------------------------------------------------
// ȉCprotected method
//---------------------------------------------------------------------------
// eLbṼZXVꂽ
void __fastcall TCFbEColumnCachedTable::ParentCellIsUpdated(int RowIndex, int ColumnIndex)
{
    TCFbECachedTable::ParentCellIsUpdated(0, ColumnIndex);
}

//---------------------------------------------------------------------------
// eLbV̍sǉꂽ
int __fastcall  TCFbEColumnCachedTable::ParentAddRow(AnsiString RowLabel)
{
    return -1;  // Ȃ
}

//---------------------------------------------------------------------------
// eLbV̗񂪒ǉꂽ
int __fastcall  TCFbEColumnCachedTable::ParentAddColumn(AnsiString ColumnLabel)
{
    if (this->GetNumberOfRows() == 0) {
        this->AddRow("row_0");
    }
    return this->AddColumn(ColumnLabel);
}

//---------------------------------------------------------------------------
// eLbV̍s폜ꂽ
void __fastcall TCFbEColumnCachedTable::ParentDeleteRowByIndex(int TargetRowIndex)
{
    return; // Ȃ
}

//---------------------------------------------------------------------------
// eLbV̗񂪍폜ꂽ
void __fastcall TCFbEColumnCachedTable::ParentDeleteColumnByIndex(int TargetColumnIndex)
{
    this->DeleteColumnByIndex(TargetColumnIndex);
}

//---------------------------------------------------------------------------
// g̃N[쐬
TCFbECachedTable* __fastcall TCFbEColumnCachedTable::CreateClone(void)
{
    TCFbEColumnCachedTable* Clone = new TCFbEColumnCachedTable();
    Clone->Assign(this);
    return Clone;       
}

//---------------------------------------------------------------------------
// g̍sƗ񂪓ւN[쐬
TCFbECachedTable* __fastcall TCFbEColumnCachedTable::CreateRotatedClone(void)
{
    TCFbERowCachedTable* Clone = new TCFbERowCachedTable();
    Clone->RotatedAssign(this);
    return Clone;
}

//---------------------------------------------------------------------------

==> docfbe_2_3_37_64.zip: docfbe_2_3_37_64/source/TCFbEColumnCachedTable.cpp <==
/*
    TCFbEColumnCachedTable.cpp    November 29, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#pragma hdrstop

#include "TCFbEColumnCachedTable.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
//---------------------------------------------------------------------------
// RXgN^iLbV쐬
__fastcall TCFbEColumnCachedTable::TCFbEColumnCachedTable(void)
    : TCFbECachedTable()
{
}

//---------------------------------------------------------------------------
// fXgN^
__fastcall TCFbEColumnCachedTable::~TCFbEColumnCachedTable()
{
}

//---------------------------------------------------------------------------
// ȉCprotected method
//---------------------------------------------------------------------------
// eLbṼZXVꂽ
void __fastcall TCFbEColumnCachedTable::ParentCellIsUpdated(int RowIndex, int ColumnIndex)
{
    TCFbECachedTable::ParentCellIsUpdated(0, ColumnIndex);
}

//---------------------------------------------------------------------------
// eLbV̍sǉꂽ
int __fastcall  TCFbEColumnCachedTable::ParentAddRow(const char* RowLabel)
{
    return -1;  // Ȃ
}

//---------------------------------------------------------------------------
// eLbV̗񂪒ǉꂽ
int __fastcall  TCFbEColumnCachedTable::ParentAddColumn(const char* ColumnLabel)
{
    if (this->GetNumberOfRows() == 0) {
        this->AddRow("row_0");
    }
    return this->AddColumn(ColumnLabel);
}

//---------------------------------------------------------------------------
// eLbV̍s폜ꂽ
void __fastcall TCFbEColumnCachedTable::ParentDeleteRowByIndex(int TargetRowIndex)
{
    return; // Ȃ
}

//---------------------------------------------------------------------------
// eLbV̗񂪍폜ꂽ
void __fastcall TCFbEColumnCachedTable::ParentDeleteColumnByIndex(int TargetColumnIndex)
{
    this->DeleteColumnByIndex(TargetColumnIndex);
}

//---------------------------------------------------------------------------
// g̃N[쐬
TCFbECachedTable* __fastcall TCFbEColumnCachedTable::CreateClone(void)
{
    TCFbEColumnCachedTable* Clone = new TCFbEColumnCachedTable();
    Clone->Assign(this);
    return Clone;       
}

//---------------------------------------------------------------------------
// g̍sƗ񂪓ւN[쐬
TCFbECachedTable* __fastcall TCFbEColumnCachedTable::CreateRotatedClone(void)
{
    TCFbERowCachedTable* Clone = new TCFbERowCachedTable();
    Clone->RotatedAssign(this);
    return Clone;
}

//---------------------------------------------------------------------------
